@@ -56,7 +56,7 @@ class baseHelper
         if(!is_object(${$objName}) or empty($key)) return false;
         $key   = str_replace('.', '->', $key);
         $value = serialize($value);
-        $code  = ("\$${objName}->{$key}=unserialize(<<<EOT\n$value\nEOT\n);");
+        $code  = ("\${$objName}->{$key}=unserialize(<<<EOT\n$value\nEOT\n);");
         eval($code);
         return true;
     }
@@ -86,7 +86,7 @@ class baseHelper
         /* 设置$appName和$moduleName。Set appName and moduleName. */
         global $app, $config;
 
-        if(str_contains($moduleName, '.'))
+        if(strpos($moduleName, '.') !== false)
         {
             [$appName, $moduleName] = explode('.', $moduleName);
         }
@@ -187,10 +187,10 @@ class baseHelper
     {
         global $config;
 
-        $sign = !str_contains($link, '?') ? "?" : "&";
+        $sign = strpos($link, '?') === false ? "?" : "&";
         $appendString = '';
         if($onlyBody or (self::inOnlyBodyMode() && !self::isAjaxRequest('modal'))) $appendString = $sign . "onlybody=yes";
-        if(self::isWithTID() and !str_contains($link, 'tid=')) $appendString .= empty($appendString) ? "{$sign}tid={$_GET['tid']}" : "&tid={$_GET['tid']}";
+        if(self::isWithTID() and strpos($link, 'tid=') === false) $appendString .= empty($appendString) ? "{$sign}tid={$_GET['tid']}" : "&tid={$_GET['tid']}";
         return $link . $appendString;
     }
 
@@ -253,7 +253,7 @@ class baseHelper
     static public function importControl($moduleName)
     {
         global $app;
-        return helper::import($app->getModulePath($moduleName) . 'control.php');
+        return helper::import($app->getModulePath('', $moduleName) . 'control.php');
     }
 
     /**
@@ -536,14 +536,14 @@ class baseHelper
         $agent = $_SERVER["HTTP_USER_AGENT"];
 
         /* Chrome should check before safari.*/
-        if(str_contains((string) $agent, 'Firefox')) $browser['name'] = "firefox";
-        if(str_contains((string) $agent, 'Opera'))   $browser['name'] = 'opera';
-        if(str_contains((string) $agent, 'Safari'))  $browser['name'] = 'safari';
-        if(str_contains((string) $agent, 'Chrome'))  $browser['name'] = "chrome";
+        if(strpos((string) $agent, 'Firefox') !== false) $browser['name'] = "firefox";
+        if(strpos((string) $agent, 'Opera') !== false)   $browser['name'] = 'opera';
+        if(strpos((string) $agent, 'Safari') !== false)  $browser['name'] = 'safari';
+        if(strpos((string) $agent, 'Chrome') !== false)  $browser['name'] = "chrome";
 
         // Check the name of browser
-        if(str_contains((string) $agent, 'MSIE') || strpos((string) $agent, 'rv:11.0')) $browser['name'] = 'ie';
-        if(str_contains((string) $agent, 'Edge')) $browser['name'] = 'edge';
+        if(strpos((string) $agent, 'MSIE') !== false || strpos((string) $agent, 'rv:11.0')) $browser['name'] = 'ie';
+        if(strpos((string) $agent, 'Edge') !== false) $browser['name'] = 'edge';
 
         // Check the version of browser
         if(preg_match('/MSIE\s(\d+)\..*/i', (string) $agent, $regs))       $browser['version'] = $regs[1];
@@ -551,7 +551,7 @@ class baseHelper
         if(preg_match('/Opera[\s|\/](\d+)\..*/i', (string) $agent, $regs)) $browser['version'] = $regs[1];
         if(preg_match('/Chrome\/(\d+)\..*/i', (string) $agent, $regs))     $browser['version'] = $regs[1];
 
-        if((!str_contains((string) $agent, 'Chrome')) && preg_match('/Safari\/(\d+)\..*$/i', (string) $agent, $regs)) $browser['version'] = $regs[1];
+        if((strpos((string) $agent, 'Chrome') === false) && preg_match('/Safari\/(\d+)\..*$/i', (string) $agent, $regs)) $browser['version'] = $regs[1];
         if(preg_match('/rv:(\d+)\..*/i', (string) $agent, $regs)) $browser['version'] = $regs[1];
         if(preg_match('/Edge\/(\d+)\..*/i', (string) $agent, $regs)) $browser['version'] = $regs[1];
 
@@ -729,7 +729,7 @@ class baseHelper
         global $config;
 
         /* 去除域名中的端口部分。Remove the port part of the domain. */
-        if(str_contains($domain, ':')) $domain = substr($domain, 0, strpos($domain, ':'));
+        if(strpos($domain, ':') !== false) $domain = substr($domain, 0, strpos($domain, ':'));
         $domain = strtolower($domain);
 
         /* $config里面有定义或者是localhost，直接返回。 Return directly if defined in $config or is localhost. */
@@ -742,15 +742,15 @@ class baseHelper
 
         /* 类似a.com的形式。 Domain like a.com. */
         $postfix = str_replace($items[0] . '.', '', $domain);
-        if(isset($config->domainPostfix) and str_contains((string) $config->domainPostfix, "|$postfix|")) return $items[0];
+        if(isset($config->domainPostfix) and strpos((string) $config->domainPostfix, "|$postfix|") !== false) return $items[0];
 
         /* 类似www.a.com的形式。 Domain like www.a.com. */
         $postfix = str_replace($items[0] . '.' . $items[1] . '.', '', $domain);
-        if(isset($config->domainPostfix) and str_contains((string) $config->domainPostfix, "|$postfix|")) return $items[1];
+        if(isset($config->domainPostfix) and strpos((string) $config->domainPostfix, "|$postfix|") !== false) return $items[1];
 
         /* 类似xxx.sub.a.com的形式。 Domain like xxx.sub.a.com. */
         $postfix = str_replace($items[0] . '.' . $items[1] . '.' . $items[2] . '.', '', $domain);
-        if(isset($config->domainPostfix) and str_contains((string) $config->domainPostfix, "|$postfix|")) return $items[0];
+        if(isset($config->domainPostfix) and strpos((string) $config->domainPostfix, "|$postfix|") !== false) return $items[0];
 
         return '';
     }
@@ -831,20 +831,14 @@ class baseHelper
         if(empty($sessionID)) $sessionID = sha1((string)mt_rand(0, mt_getrandmax()));
 
         session_write_close();
-        session_id($sessionID);
-        if(ini_get('session.save_handler') == 'user' and isset($_GET['tid']))
+
+        if(ini_get('session.save_handler') == 'user')
         {
-            $ztSessionHandler = new ztSessionHandler($_GET['tid']);
-            session_set_save_handler(
-                $ztSessionHandler->open(...),
-                $ztSessionHandler->close(...),
-                $ztSessionHandler->read(...),
-                $ztSessionHandler->write(...),
-                $ztSessionHandler->destroy(...),
-                $ztSessionHandler->gc(...)
-            );
-            register_shutdown_function('session_write_close');
+            $ztSessionHandler = new ztSessionHandler();
+            session_set_save_handler($ztSessionHandler, true);
         }
+
+        session_id($sessionID);
         session_start();
 
         global $app;
@@ -870,7 +864,7 @@ class baseHelper
         $errorMsg   = zget($errorInfo, 2, '');
         $message    = $exception->getMessage();
 
-        if(str_contains($repairCode, "|$errorCode|") or ($errorCode == '1016' and str_contains((string) $errorMsg, 'errno: 145')) or str_contains((string) $message, 'repair'))
+        if(strpos($repairCode, "|$errorCode|") !== false or ($errorCode == '1016' and strpos((string) $errorMsg, 'errno: 145') !== false) or strpos((string) $message, 'repair') !== false)
         {
             if(isset($config->framework->autoRepairTable) and $config->framework->autoRepairTable)
             {
@@ -1265,7 +1259,7 @@ function isLocalIP()
     if(isset($config->isLocalIP)) return $config->isLocalIP;
     $serverIP = $_SERVER['SERVER_ADDR'];
     if($serverIP == '127.0.0.1' or $serverIP == '::1') return true;
-    if(str_contains((string) $serverIP, '10.70')) return false;
+    if(strpos((string) $serverIP, '10.70') !== false) return false;
     return !filter_var($serverIP, FILTER_VALIDATE_IP, FILTER_FLAG_NO_PRIV_RANGE);
 }
 
@@ -1439,7 +1433,7 @@ if(!function_exists('getallheaders'))
         $headers = array();
         foreach($_SERVER as $name => $value)
         {
-            if(str_starts_with($name, 'HTTP_'))
+            if(strncmp($name, 'HTTP_', strlen('HTTP_')) === 0)
             {
                 $headers[str_replace(' ', '-', ucwords(strtolower(str_replace('_', ' ', substr($name, 5)))))] = $value;
             }
@@ -1472,3 +1466,71 @@ if(!interface_exists('JsonSerializable'))
         return $data;
     }
 }
+
+/**
+ * 把一个或多个数组附加到第一个数组，用于替换数组 + 运算符。
+ * Append one or more arrays to the first array, used to replace the array + operator.
+ *
+ * reference: https://www.php.net/manual/en/language.operators.array.php.
+ *
+ * @param  array ...$args
+ * @return array
+ */
+function arrayUnion(...$args)
+{
+    $args = array_filter($args, function($arg){return is_array($arg);});
+
+    $count = count($args);
+    if($count == 0) return [];
+    if($count == 1) return reset($args);
+
+    $result = array_shift($args);
+    foreach($args as $arg)
+    {
+        foreach($arg as $key => $value)
+        {
+            if(!isset($result[$key])) $result[$key] = $value;
+        }
+    }
+    return $result;
+}
+
+/**
+ * 压缩 ID 列表。
+ * Compress ID list.
+ *
+ * @param  string|array $idList
+ * @access public
+ * @return string
+ */
+function compress($idList)
+{
+    if(is_string($idList)) $idList = array_filter(explode(',', $idList));
+    if(!is_array($idList)) return $idList;
+
+    $firstID = reset($idList);
+    if(!is_numeric($firstID) || (float)$firstID != $firstID) return $idList; // If the first ID is not numeric, return the original array.
+
+    $idList = array_values($idList);
+    asort($idList);
+
+    $encoded = [$idList[0]];
+    for($i = 1; $i < count($idList); $i++) $encoded[] = $idList[$i] - $idList[$i-1];
+
+    return gzcompress(implode(',', $encoded));
+}
+
+/**
+ * 解压缩 ID 列表。
+ * Uncompress ID list.
+ *
+ * @param  string $encoded
+ * @access public
+ * @return array
+ */
+function uncompress($encoded)
+{
+    $decoded = explode(',', gzuncompress($encoded));
+    for($i = 1; $i < count($decoded); $i++) $decoded[$i] += $decoded[$i-1];
+    return $decoded;
+}
