@@ -633,11 +633,12 @@ class gitlabModel extends model
         if(empty($result)) return array('pager' => null, 'projects' => array());
 
         $header     = $result['header'];
-        $recTotal   = isset($header['X-Total']) ? $header['X-Total']: $header['x-total'];
-        $recPerPage = isset($header['X-Per-Page']) ? $header['X-Per-Page'] : $header['x-per-page'];
+        $recTotal   = isset($header['X-Total']) ? $header['X-Total']: zget($header, 'x-total', 0);
+        $recPerPage = isset($header['X-Per-Page']) ? $header['X-Per-Page'] : zget($header, 'x-per-page', 0);
 
         $this->app->loadClass('pager', true);
         $pager = pager::init($recTotal, $recPerPage, $pager->pageID);
+        if(empty($recTotal)) return array('pager' => $pager, 'projects' => array());
 
         return array('pager' => $pager, 'projects' => json_decode($result['body']));
     }
@@ -1060,6 +1061,7 @@ class gitlabModel extends model
      * @access public
      * @link   https://docs.gitlab.com/ee/api/projects.html#list-project-hooks
      * @return object|array|null
+     * @param int $hookID
      */
     public function apiGetHooks($gitlabID, $projectID, $hookID = 0)
     {
@@ -1714,6 +1716,7 @@ class gitlabModel extends model
      * @param  object $issue
      * @access public
      * @return void
+     * @param object $object
      */
     public function saveImportedIssue($gitlabID, $projectID, $objectType, $objectID, $issue, $object)
     {
@@ -1761,6 +1764,7 @@ class gitlabModel extends model
      * @param  int    $gitlabID
      * @access public
      * @return bool
+     * @param object $project
      */
     public function editProject($gitlabID, $project)
     {
@@ -1840,6 +1844,7 @@ class gitlabModel extends model
      * @param  int    $gitlabID
      * @access public
      * @return bool
+     * @param object $gitlabUser
      */
     public function editUser($gitlabID, $gitlabUser)
     {
